@@ -20,4 +20,4 @@ framework_map = {
 def log_request(json: dict):
     json['method'] = method_map[json['method']]
     json['framework'] = framework_map[json['framework']]
-    requests.post('https://api-analytics-server.vercel.app/api/log-request', json=json)
+    requests.post('https://api-analytics-server.vercel.app/api/log-request', json=json, timeout=5, verify=False)
